@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+# -*- coding: utf-8 -*-
 import os
 import argparse
 import sys
@@ -6,13 +6,14 @@ import sys
 from scipioninstaller import INSTALL_ENTRY
 # Virtual env programs
 from scipioninstaller.launchers import (LAUNCHER_TEMPLATE, VIRTUAL_ENV_VAR,
-                                        ACTIVATE_ENV_CMD, PYTHON_PROGRAM)
+                                        ACTIVATE_ENV_CMD, PYTHON_PROGRAM, CONDA_ACTIVATION_LINE)
 
 VENV_ARG = '-venv'
 
 CMD_SEP = " &&\n"
 CONDA = 'conda'
-SCIPION_ENV = '.scipion3env'
+CONDA_ACTIVATION_CMD = "CONDA_ACTIVATION_CMD"
+SCIPION_ENV = 'scipion3'
 GIT = 'git'
 LAUNCHER_NAME = "scipion3"
 
@@ -56,24 +57,36 @@ def getCondaCmd(scipionEnv, noAsk):
 
     silentMode = "-y" if noAsk else ""
     cmd = cmdfy(getCondaInitCmd())
-    cmd += cmdfy("%s create %s -n %s python=3" % (CONDA, silentMode, scipionEnv))
+    cmd += cmdfy("%s create %s -n %s python=3.8" % (CONDA, silentMode, scipionEnv))
     cmd += cmdfy(getCondaenvActivationCmd(scipionEnv))
     return cmd
 
-def getCondaInitCmd():
-    shell = os.path.basename(os.environ.get("SHELL", "bash"))
-    if shell in ["csh", "tcsh"]:
-        return 'set cinit="`%s shell.%s hook`" && eval "$cinit"' % (checkProgram(CONDA), shell)
+
+def getCondaInitCmd(doRaise=True):
+
+    conda_init = os.environ.get(CONDA_ACTIVATION_CMD, None)
+
+    if conda_init is None:
+        return guessCondaInitCmd(doRaise)
     else:
-        return 'eval "$(%s shell.%s hook)"' % (checkProgram(CONDA), shell)
+        return conda_init
+
+def guessCondaInitCmd(doRaise=True):
+
+    shell = os.path.basename(os.environ.get("SHELL", "bash"))
+    condaPath = checkProgram(CONDA, doRaise)
+    if not condaPath:
+        return ""
+    if shell in ["csh", "tcsh", "zsh"]:
+        return '. "%s"' % os.path.join(os.path.dirname(condaPath), "..", "etc",
+                                       "profile.d", "conda.sh")
+    else:
+        return 'eval "$(%s shell.%s hook)"' % (condaPath, shell)
 
 
 def getCondaenvActivationCmd(scipionEnv):
-    shell = os.path.basename(os.environ.get("SHELL", "bash"))
-    if shell in ["csh", "tcsh"]:
-        return 'set cact="`%s shell.%s activate %s`" && eval "$cact"' % (checkProgram(CONDA), shell, scipionEnv)
-    else:
-        return "conda activate %s" % scipionEnv
+
+    return "conda activate %s" % scipionEnv
 
 
 def cmdfy(cmd, sep=CMD_SEP):
@@ -110,15 +123,16 @@ def checkProgram(program, doRaise=True):
     else:
         return fullPath
 
-def solveScipionHome(scipionHome, dry, noAsk):
+def solveScipionHome(scipionHome, dry):
     # Check folder exists
     if not os.path.exists(scipionHome):
 
         try:
             if not dry:
-                os.mkdir(scipionHome)
+                os.makedirs(scipionHome)
             else:
                 print ("%s would have been created." % scipionHome)
+
         except OSError as e:
             print (e)
             raise InstallationError("Please, verify that you have "
@@ -198,15 +212,24 @@ def createLauncher(scipionHome, conda, dry, scipionEnv, devel=False):
         content = LAUNCHER_TEMPLATE
 
     pythonProgram = os.path.basename(sys.executable)
+
+    condaInit = getCondaInitCmd(doRaise=False)
+
     if conda:
         replaceDict = {VIRTUAL_ENV_VAR: "CONDA_DEFAULT_ENV",
-                       ACTIVATE_ENV_CMD: getCondaInitCmd() + " && " + getCondaenvActivationCmd(scipionEnv),
+                       ACTIVATE_ENV_CMD: condaInit + " && " + getCondaenvActivationCmd(scipionEnv),
                        PYTHON_PROGRAM: str(pythonProgram)}
     else:
         replaceDict = {VIRTUAL_ENV_VAR: "VIRTUAL_ENV",
                        ACTIVATE_ENV_CMD: getVirtualenvActivationCmd(scipionHome, scipionEnv),
                        PYTHON_PROGRAM: str(pythonProgram)}
 
+    # Add CONDA_ACTIVATION_CMD variable if possible
+    if condaInit:
+        replaceDict[CONDA_ACTIVATION_LINE] = "os.environ['CONDA_ACTIVATION_CMD'] = '%s'" % condaInit
+    else:
+        replaceDict[CONDA_ACTIVATION_LINE] = ""
+
     # Replace values
     content = content % replaceDict
 
@@ -229,7 +252,13 @@ def createLauncher(scipionHome, conda, dry, scipionEnv, devel=False):
 def main():
     try:
         # Arg parser configuration
-        parser = argparse.ArgumentParser(prog=INSTALL_ENTRY, epilog="Happy Scipioning!")
+        parser = argparse.ArgumentParser(prog=INSTALL_ENTRY,
+                                         description= "Installs scipion3 in a conda or virtualenv environment.\n"
+                                                      "Check all parameters bellow for a custom installation. If there are issues initializing "
+                                                      " conda you can set %s variable and it will be used instead of guessing.\n "
+                                                      "Typical values are . \"/path/to/miniconda3/etc/profile.d/conda.sh\" or "
+                                                      "eval \"$(/path/to/miniconda3/bin/conda shell.bash hook)\"" % CONDA_ACTIVATION_CMD,
+                                         epilog="Happy Scipioning!")
         parser.add_argument('path',
                             help='Location where you want scipion to be installed.')
         parser.add_argument('-conda',
@@ -287,7 +316,7 @@ def main():
             # If conda is detected
             if checkProgram(CONDA, doRaise=False):
                 print("%s detected. Favouring it. If you want a virtualenv installation "
-                      "cancel installation and pass -%s ." % (CONDA, VENV_ARG))
+                      "cancel installation and pass %s ." % (CONDA, VENV_ARG))
                 conda = True
             else:
                 # Fall back to virtualenv
@@ -299,8 +328,10 @@ def main():
 
         checkProgram(GIT) if dev else None
         # Check Scipion home folder and create it if apply.
-        solveScipionHome(scipionHome, dry, noAsk)
+        solveScipionHome(scipionHome, dry)
         scipionEnv = args.n
+        if not conda and scipionEnv == SCIPION_ENV:
+            scipionEnv = '.' + scipionEnv
 
         cmd = getEnvironmentCreationCmd(conda, scipionHome, scipionEnv, noAsk)
         cmd += getInstallationCmd(scipionHome, dev, args)
@@ -310,19 +341,57 @@ def main():
 
         launcher = createLauncher(scipionHome, conda, dry, scipionEnv, dev)
         if not dry:
-            print("\n\nScipion has been successfully installed!! Happy EM processing!!\n\n")
-            print("You can launch Scipion using the launcher at %s\n" % launcher )
+            header = "Scipion has been successfully installed!! Happy EM processing!!"
+            content = "You can launch Scipion using the launcher at: %s " % launcher
+            createMessageInstallation(header, [content])
 
     except InstallationError as e:
-        print(str(e))
-        print("Installation cancelled.")
+        header = "Installation failed"
+        content = []
+        errors = str(e).split("\n")
+        for error in errors:
+            content.append(error)
+        content.append(" ")
+        content.append("For more information about the installation errors that can appear when installing or ")
+        content.append("using Scipion go to: https://scipion-em.github.io/docs/docs/user/troubleshooting.html ")
+        createMessageInstallation(header, content)
         sys.exit(-1)
     except KeyboardInterrupt as e:
-        print("\nInstallation cancelled, probably by pressing \"Ctrl + c\".")
+        header = "Installation cancelled"
+        content = []
+        content.append("The installation has been interrupted, probably by pressing \"Ctrl + c\".")
+        createMessageInstallation(header, content)
         sys.exit(-1)
 
-def runCmd(cmd, dry):
 
+def createMessageInstallation(header="", content=[]):
+    """
+    Create a table related with Scipion installation
+    """
+    requiredWidth = max([len(c) for c in content])
+
+    horizontalLine = "_" * requiredWidth
+
+    topTable = " _" + horizontalLine + " "
+    emptyLine = "| " + " " * requiredWidth + "|"
+    botomTable = " _" + horizontalLine + " "
+    divRowTable = botomTable
+    print("")
+    print(topTable)
+    print(emptyLine)
+    numberOfSpaces = requiredWidth - len(header)
+    headerContent = "| " + header + " " * numberOfSpaces  + "|"
+    print(headerContent)
+    print(divRowTable)
+    print("")
+    for line in content:
+        numberOfSpaces = requiredWidth - len(line)
+        lineContend = "  " + line
+        print(lineContend)
+    print(botomTable)
+
+
+def runCmd(cmd, dry):
     # remove last CMD_SEP
     if cmd.endswith(CMD_SEP):
         cmd = cmd[:-len(CMD_SEP)]
@@ -332,7 +401,7 @@ def runCmd(cmd, dry):
     else:
         val = os.system(cmd)
         if val != 0:
-            raise InstallationError("Something went wrong running: \n %s" % cmd)
+            raise InstallationError("Something went wrong (SEE ERRORS ABOVE) when running: \n\n %s" % cmd)
 
 
 if __name__ == '__main__':
